@@ -24,7 +24,7 @@ int main (int argc, char const *const *argv)
   unsigned int perms = 0777 ;
   PROG = "s6-ipcserver-socketbinder" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "DdMmBb:a:", &l) ;
