@@ -14,6 +14,7 @@
 #include <skalibs/exec.h>
 
 #include <s6/config.h>
+#include "s6lockd.h"
 
 #define USAGE "s6-setlock [ -r | -w ] [ -n | -N | -t timeout ] lockfile prog..."
 #define dieusage() strerr_dieusage(100, USAGE)
@@ -25,7 +26,7 @@ int main (int argc, char const *const *argv)
   PROG = "s6-setlock" ;
   for (;;)
   {
-    int opt = subgetopt(argc, argv, "nNrwt:") ;
+    int opt = lgetopt(argc, argv, "nNrwt:") ;
     if (opt == -1) break ;
     switch (opt)
     {
@@ -40,21 +41,13 @@ int main (int argc, char const *const *argv)
   argc -= subgetopt_here.ind ; argv += subgetopt_here.ind ;
   if (argc < 2) dieusage() ;
 
-  if (nb < 2)
-  {
-    int r ;
-    int fd = open_create(argv[0]) ;
-    if (fd < 0) strerr_diefu2sys(111, "open_create ", argv[0]) ;
-    r = fd_lock(fd, ex, nb) ;
-    if (!r) errno = EBUSY ;
-    if (r < 1) strerr_diefu2sys(1, "lock ", argv[0]) ;
-  }
+  if (nb < 2) s6lockd_openandlock(argv[0], ex, nb) ;
   else
   {
     char const *cargv[4] = { "s6lockd-helper", ex ? "w" : "r", argv[0], 0 } ;
     char const *nullenv = { 0 } ;
     iopause_fd x = { .events = IOPAUSE_READ } ;
-    tain_t deadline ;
+    tain deadline ;
     int p[2] = { 0, 1 } ;
     pid_t pid ;
     char c ;
