@@ -31,7 +31,7 @@ int main (int argc, char const *const *argv)
   char const *rulesfile = 0 ;
   PROG = "s6-fdholder-daemon" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "Dd1Uv:c:n:b:u:g:G:t:T:i:x:", &l) ;
