@@ -4,10 +4,10 @@
 #define S6_H
 
 #include <s6/compat.h>
-#include <s6/s6-supervise.h>
+#include <s6/supervise.h>
 #include <s6/ftrigr.h>
 #include <s6/ftrigw.h>
 #include <s6/accessrules.h>
-#include <s6/s6lock.h>
+#include <s6/lock.h>
 
 #endif
