@@ -4,7 +4,7 @@
 #include <skalibs/uint16.h>
 #include <skalibs/uint64.h>
 #include <skalibs/tai.h>
-#include <s6/s6-supervise.h>
+#include <s6/supervise.h>
 
 void s6_svstatus_pack (char *pack, s6_svstatus_t const *sv)
 {
@@ -15,8 +15,6 @@ void s6_svstatus_pack (char *pack, s6_svstatus_t const *sv)
   pack[34] =
     sv->flagpaused |
     (sv->flagfinishing << 1) |
-    (sv->flagwant << 2) |
-    (sv->flagwantup << 3) |
-    (sv->flagready << 4) |
-    (sv->flagthrottled << 5) ;
+    (sv->flagwantup << 2) |
+    (sv->flagready << 3) ;
 }
