@@ -2,7 +2,7 @@
 
 #include <skalibs/sgetopt.h>
 #include <skalibs/strerr2.h>
-#include <s6/s6-supervise.h>
+#include <s6/supervise.h>
 
 #define USAGE "s6-svscanctl [ -zabhitqnN ] svscandir"
 #define dieusage() strerr_dieusage(100, USAGE)
@@ -15,7 +15,7 @@ int main (int argc, char const *const *argv)
   unsigned int datalen = 0 ;
   PROG = "s6-svscanctl" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "phratszbnNiq0678", &l) ;
