@@ -1,18 +1,20 @@
 /* ISC license. */
 
 #include <signal.h>
+
 #include <skalibs/strerr2.h>
 #include <skalibs/sig.h>
 #include <skalibs/djbunix.h>
 #include <skalibs/selfpipe.h>
+
 #include "s6-svlisten.h"
 
 int s6_svlisten_selfpipe_init (void)
 {
   int spfd = selfpipe_init() ;
   if (spfd < 0) strerr_diefu1sys(111, "selfpipe_init") ;
-  if (selfpipe_trap(SIGCHLD) < 0) strerr_diefu1sys(111, "selfpipe_trap") ;
-  if (sig_ignore(SIGPIPE) < 0) strerr_diefu1sys(111, "ignore SIGPIPE") ;
+  if (!selfpipe_trap(SIGCHLD)) strerr_diefu1sys(111, "selfpipe_trap") ;
+  if (!sig_altignore(SIGPIPE)) strerr_diefu1sys(111, "ignore SIGPIPE") ;
   return spfd ;
 }
 
@@ -26,4 +28,3 @@ void s6_svlisten_signal_handler (void)
     default : strerr_dief1x(101, "unexpected data in selfpipe") ;
   }
 }
-
